
.. _config:

Tree configurations
-------------------

The SDSS tree provides multiple environment path configurations.  The current available
configurations are the following:

* :ref:`sdsswork <sdsswork>` - the latest working configuration
* :ref:`DR16 <dr16>` - the environment configuration for public data release 16
* :ref:`DR15 <dr15>`
* :ref:`DR14 <dr14>`
* :ref:`DR13 <dr13>`
* :ref:`DR12 <dr12>`
* :ref:`DR11 <dr11>`
* :ref:`DR10 <dr10>`
* :ref:`DR9 <dr9>`
* :ref:`DR18<dr8>`
* :ref:`sdss5<sdss5>` - the temporary SDSS-V configuration

How has the Tree evolved over Data Releases
-------------------------------------------

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr16, dr15
   :remove-sasbase:

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr15, dr14
   :remove-sasbase:

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr14, dr13
   :remove-sasbase:

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr13, dr12
   :remove-sasbase:

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr12, dr11
   :remove-sasbase:

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr11, dr10
   :remove-sasbase:

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr10, dr9
   :remove-sasbase:

.. changelog:: tree.changelog:compute_changelog
   :prog: changes
   :drs: dr9, dr8
   :remove-sasbase:

